@@ -22,12 +22,3 @@ plotcv <- function(x, stack = FALSE, index.res = 1, col = index.res, ...) {
 	if (m > 0.8*max(pointwise)) {pos=2} else {pos=4}
 	text(x=global, y=0.1, label="global cv", pos=pos)
 }
-
-plotecdf <- function (LHS, stack=FALSE, index.res =1:get.noutputs(LHS), col=index.res, ...) {
-	if (stack) {
-		dat <- vec(get.results(LHS)[,index.res])
-		g <- rep(index.res, each=dim(LHS$res)[1])
-		Ecdf(dat, group=g, col=col)
-	} else Ecdf(get.results(LHS)[,index.res])
-}
-
